netapp_ontap.models.fpolicy_event_file_operations API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.fpolicy_event_file_operations`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FpolicyEventFileOperationsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FpolicyEventFileOperations object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `close GET POST PATCH`

    File close operations

  `create GET POST PATCH`

    File create operations

  `create_dir GET POST PATCH`

    Directory create operations

  `delete GET POST PATCH`

    File delete operations

  `delete_dir GET POST PATCH`

    Directory delete operations

  `getattr GET POST PATCH`

    Get attribute operations

  `link GET POST PATCH`

    Link operations

  `lookup GET POST PATCH`

    Lookup operations

  `open GET POST PATCH`

    File open operations

  `read GET POST PATCH`

    File read operations

  `rename GET POST PATCH`

    File rename operations

  `rename_dir GET POST PATCH`

    Directory rename operations

  `setattr GET POST PATCH`

    Set attribute operations

  `symlink GET POST PATCH`

    Symbolic link operations

  `write GET POST PATCH`

    File write operations